@@ -23,8 +23,10 @@ class StatcordClient:
         self.custom_2 = custom_2
 
         # validate args
-        if not isinstance(bot, commands.Bot):
-            raise TypeError("The bot argument must be or be a subclass of discord.ext.commands.Bot")
+        if not isinstance(bot, (commands.Bot, commands.AutoShardedBot)):
+            raise TypeError(
+                "The bot argument must be or be a subclass of discord.ext.commands.Bot or discord.ext.commands.AutoShardedBot"
+            )
 
         if not isinstance(statcord_key, str):
             raise TypeError("The statcord_key argument must be a string.")
